==> mapmyindia_gl-0.2.0.tar.gz: lib/src/api/autosuggest/autosuggest_response.dart <==
part of mapmyindia_gl;

class AutoSuggestResponse {
  List<ELocation>? suggestedLocations;
  List<ELocation>? userAddedLocations;
  List<SuggestedSearch>? suggestedSearches;

  static AutoSuggestResponse fromMap(Map<String, dynamic> map) {
    AutoSuggestResponse autoSuggestResponse = AutoSuggestResponse();
    if (map.containsKey("suggestedLocations")) {
      List<dynamic> suggestedLocations =
          map['suggestedLocations'] as List<dynamic>;
      autoSuggestResponse.suggestedLocations =
          List.generate(suggestedLocations.length, (index) {
        return ELocation.fromMap(
            suggestedLocations[index] as Map<String, dynamic>);
      });
    }
    if (map.containsKey("userAddedLocations")) {
      List<dynamic> userAddedLocations =
          map['userAddedLocations'] as List<dynamic>;
      autoSuggestResponse.userAddedLocations =
          List.generate(userAddedLocations.length, (index) {
        return ELocation.fromMap(
            userAddedLocations[index] as Map<String, dynamic>);
      });
    }
    if (map.containsKey("suggestedSearches")) {
      List<dynamic> userAddedLocations =
          map['suggestedSearches'] as List<dynamic>;
      autoSuggestResponse.suggestedSearches =
          List.generate(userAddedLocations.length, (index) {
        return SuggestedSearch.fromMap(
            userAddedLocations[index] as Map<String, dynamic>);
      });
    }
    return autoSuggestResponse;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> map = <String, dynamic>{};

    if (this.suggestedLocations != null) {
      map['suggestedLocations'] =
          List.generate(this.suggestedLocations!.length, (index) {
        return this.suggestedLocations![index].toJson();
      });
    }
    if (this.suggestedSearches != null) {
      map['suggestedSearches'] =
          List.generate(this.suggestedSearches!.length, (index) {
        return this.suggestedSearches![index].toJson();
      });
    }
    if (this.userAddedLocations != null) {
      map['userAddedLocations'] =
          List.generate(this.userAddedLocations!.length, (index) {
        return this.userAddedLocations![index].toJson();
      });
    }
    return map;
  }
}

class SuggestedSearch {
  String? keyword;
  String? identifier;
  String? location;
  String? hyperLink;
  int? orderIndex;
  String? eLoc;

  static SuggestedSearch fromMap(Map<String, dynamic> map) {
    SuggestedSearch suggestedSearchesBean = SuggestedSearch();
    suggestedSearchesBean.keyword = map['keyword'] as String?;
    suggestedSearchesBean.identifier = map['identifier'] as String?;
    suggestedSearchesBean.location = map['location'] as String?;
    suggestedSearchesBean.hyperLink = map['hyperLink'] as String?;
    suggestedSearchesBean.orderIndex = map['orderIndex'] as int?;
    suggestedSearchesBean.eLoc = map['eLoc'] as String?;
    return suggestedSearchesBean;
  }

  Map toJson() => {
        "keyword": keyword,
        "identifier": identifier,
        "location": location,
        "hyperLink": hyperLink,
        "orderIndex": orderIndex,
        "eLoc": eLoc,
      };
}

class ELocation {
  String? type;
  int? typeX;
  String? placeAddress;
  String? latitude;
  String? longitude;
  String? eLoc;
  double? entryLatitude;
  double? entryLongitude;
  String? placeName;
  String? alternateName;
  List<String>? keywords;
  AddressToken? addressTokens;
  String? userName;
  int? p;
  int? orderIndex;

  static ELocation fromMap(Map<String, dynamic> map) {
    ELocation eLocation = ELocation();
    eLocation.type = map['type'];
    eLocation.typeX = map['typeX'];
    eLocation.placeAddress = map['addr'] as String?;
    eLocation.latitude = map['y'];
    eLocation.longitude = map['x'];
    eLocation.eLoc = map['elc'] as String?;
    if(map.containsKey('entryLatitude')) {
      eLocation.entryLatitude = (map['entryLatitude']).toDouble();
    }
    if(map.containsKey('entryLongitude')) {
      eLocation.entryLongitude = (map['entryLongitude']).toDouble();
    }
    eLocation.placeName = map['placeName'];
    eLocation.alternateName = map['alternateName'];
    eLocation.userName = map['user'];
    if (map.containsKey('keywords')) {
      List<dynamic> keywords = map['keywords'] as List<dynamic>;
      eLocation.keywords = List.generate(keywords.length, (index) {
        return keywords[index] as String;
      });
    }
    if (map.containsKey('addressTokens')) {
      eLocation.addressTokens =
          AddressToken.fromMap(map['addressTokens']);
    }
    eLocation.p = map['p'];
    eLocation.orderIndex = map['orderIndex'];
    return eLocation;
  }

  Map<String, dynamic> toJson() => <String, dynamic>{
        "type": type,
        "typeX": typeX,
        "addr": placeAddress,
        "y": latitude,
        "x": longitude,
        "elc": eLoc,
        "entryLatitude": entryLatitude,
        "entryLongitude": entryLongitude,
        "placeName": placeName,
        "alternateName": alternateName,
        "user": userName,
        "keywords": keywords,
        "addressTokens": addressTokens?.toJson(),
        "p": p,
        "orderIndex": orderIndex,
      };
}

/// houseNumber : ""
/// houseName : ""
/// poi : "Coronation Memorial"
/// street : ""
/// subSubLocality : ""
/// subLocality : ""
/// locality : "Jahangirpuri;Jhangir Puri"
/// village : ""
/// subDistrict : "Model Town"
/// district : "North District"
/// city : "New Delhi"
/// state : "Delhi"
/// pincode : "110033"

class AddressToken {
  String? houseNumber;
  String? houseName;
  String? poi;
  String? street;
  String? subSubLocality;
  String? subLocality;
  String? locality;
  String? village;
  String? subDistrict;
  String? district;
  String? city;
  String? state;
  String? pincode;

  static AddressToken fromMap(Map<String, dynamic> map) {
    AddressToken addressTokens = AddressToken();
    addressTokens.houseNumber = map['houseNumber'];
    addressTokens.houseName = map['houseName'];
    addressTokens.poi = map['poi'];
    addressTokens.street = map['street'];
    addressTokens.subSubLocality = map['subSubLocality'];
    addressTokens.subLocality = map['subLocality'];
    addressTokens.locality = map['locality'];
    addressTokens.village = map['village'];
    addressTokens.subDistrict = map['subDistrict'];
    addressTokens.district = map['district'];
    addressTokens.city = map['city'];
    addressTokens.state = map['state'];
    addressTokens.pincode = map['pincode'];
    return addressTokens;
  }

  Map toJson() => {
        "houseNumber": houseNumber,
        "houseName": houseName,
        "poi": poi,
        "street": street,
        "subSubLocality": subSubLocality,
        "subLocality": subLocality,
        "locality": locality,
        "village": village,
        "subDistrict": subDistrict,
        "district": district,
        "city": city,
        "state": state,
        "pincode": pincode,
      };
}

==> mapmyindia_gl-0.2.2.tar.gz: lib/src/api/autosuggest/autosuggest_response.dart <==
part of mapmyindia_gl;

class AutoSuggestResponse {
  List<ELocation>? suggestedLocations;
  List<ELocation>? userAddedLocations;
  List<SuggestedSearch>? suggestedSearches;

  static AutoSuggestResponse fromMap(Map<String, dynamic> map) {
    AutoSuggestResponse autoSuggestResponse = AutoSuggestResponse();
    if (map.containsKey("suggestedLocations")) {
      List<dynamic> suggestedLocations =
          map['suggestedLocations'] as List<dynamic>;
      autoSuggestResponse.suggestedLocations =
          List.generate(suggestedLocations.length, (index) {
        return ELocation.fromMap(
            suggestedLocations[index] as Map<String, dynamic>);
      });
    }
    if (map.containsKey("userAddedLocations")) {
      List<dynamic> userAddedLocations =
          map['userAddedLocations'] as List<dynamic>;
      autoSuggestResponse.userAddedLocations =
          List.generate(userAddedLocations.length, (index) {
        return ELocation.fromMap(
            userAddedLocations[index] as Map<String, dynamic>);
      });
    }
    if (map.containsKey("suggestedSearches")) {
      List<dynamic> userAddedLocations =
          map['suggestedSearches'] as List<dynamic>;
      autoSuggestResponse.suggestedSearches =
          List.generate(userAddedLocations.length, (index) {
        return SuggestedSearch.fromMap(
            userAddedLocations[index] as Map<String, dynamic>);
      });
    }
    return autoSuggestResponse;
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> map = <String, dynamic>{};

    if (this.suggestedLocations != null) {
      map['suggestedLocations'] =
          List.generate(this.suggestedLocations!.length, (index) {
        return this.suggestedLocations![index].toJson();
      });
    }
    if (this.suggestedSearches != null) {
      map['suggestedSearches'] =
          List.generate(this.suggestedSearches!.length, (index) {
        return this.suggestedSearches![index].toJson();
      });
    }
    if (this.userAddedLocations != null) {
      map['userAddedLocations'] =
          List.generate(this.userAddedLocations!.length, (index) {
        return this.userAddedLocations![index].toJson();
      });
    }
    return map;
  }
}

class SuggestedSearch {
  String? keyword;
  String? identifier;
  String? location;
  String? hyperLink;
  int? orderIndex;
  String? eLoc;

  static SuggestedSearch fromMap(Map<String, dynamic> map) {
    SuggestedSearch suggestedSearchesBean = SuggestedSearch();
    suggestedSearchesBean.keyword = map['keyword'] as String?;
    suggestedSearchesBean.identifier = map['identifier'] as String?;
    suggestedSearchesBean.location = map['location'] as String?;
    suggestedSearchesBean.hyperLink = map['hyperLink'] as String?;
    suggestedSearchesBean.orderIndex = map['orderIndex'] as int?;
    suggestedSearchesBean.eLoc = map['eLoc'] as String?;
    return suggestedSearchesBean;
  }

  Map toJson() => {
        "keyword": keyword,
        "identifier": identifier,
        "location": location,
        "hyperLink": hyperLink,
        "orderIndex": orderIndex,
        "eLoc": eLoc,
      };
}

class ELocation {
  String? type;
  int? typeX;
  String? placeAddress;
  String? latitude;
  String? longitude;
  String? eLoc;
  double? entryLatitude;
  double? entryLongitude;
  String? placeName;
  String? alternateName;
  List<String>? keywords;
  AddressToken? addressTokens;
  String? userName;
  int? p;
  int? orderIndex;

  static ELocation fromMap(Map<String, dynamic> map) {
    ELocation eLocation = ELocation();
    eLocation.type = map['type'];
    eLocation.typeX = map['typeX'];
    eLocation.placeAddress = map['addr'] as String?;
    eLocation.latitude = map['y'];
    eLocation.longitude = map['x'];
    eLocation.eLoc = map['elc'] as String?;
    if (map.containsKey('entryLatitude')) {
      eLocation.entryLatitude = (map['entryLatitude']).toDouble();
    }
    if (map.containsKey('entryLongitude')) {
      eLocation.entryLongitude = (map['entryLongitude']).toDouble();
    }
    eLocation.placeName = map['placeName'];
    eLocation.alternateName = map['alternateName'];
    eLocation.userName = map['user'];
    if (map.containsKey('keywords')) {
      List<dynamic> keywords = map['keywords'] as List<dynamic>;
      eLocation.keywords = List.generate(keywords.length, (index) {
        return keywords[index] as String;
      });
    }
    if (map.containsKey('addressTokens')) {
      eLocation.addressTokens = AddressToken.fromMap(map['addressTokens']);
    }
    eLocation.p = map['p'];
    eLocation.orderIndex = map['orderIndex'];
    return eLocation;
  }

  Map<String, dynamic> toJson() => <String, dynamic>{
        "type": type,
        "typeX": typeX,
        "addr": placeAddress,
        "y": latitude,
        "x": longitude,
        "elc": eLoc,
        "entryLatitude": entryLatitude,
        "entryLongitude": entryLongitude,
        "placeName": placeName,
        "alternateName": alternateName,
        "user": userName,
        "keywords": keywords,
        "addressTokens": addressTokens?.toJson(),
        "p": p,
        "orderIndex": orderIndex,
      };
}

/// houseNumber : ""
/// houseName : ""
/// poi : "Coronation Memorial"
/// street : ""
/// subSubLocality : ""
/// subLocality : ""
/// locality : "Jahangirpuri;Jhangir Puri"
/// village : ""
/// subDistrict : "Model Town"
/// district : "North District"
/// city : "New Delhi"
/// state : "Delhi"
/// pincode : "110033"

class AddressToken {
  String? houseNumber;
  String? houseName;
  String? poi;
  String? street;
  String? subSubLocality;
  String? subLocality;
  String? locality;
  String? village;
  String? subDistrict;
  String? district;
  String? city;
  String? state;
  String? pincode;

  static AddressToken fromMap(Map<String, dynamic> map) {
    AddressToken addressTokens = AddressToken();
    addressTokens.houseNumber = map['houseNumber'];
    addressTokens.houseName = map['houseName'];
    addressTokens.poi = map['poi'];
    addressTokens.street = map['street'];
    addressTokens.subSubLocality = map['subSubLocality'];
    addressTokens.subLocality = map['subLocality'];
    addressTokens.locality = map['locality'];
    addressTokens.village = map['village'];
    addressTokens.subDistrict = map['subDistrict'];
    addressTokens.district = map['district'];
    addressTokens.city = map['city'];
    addressTokens.state = map['state'];
    addressTokens.pincode = map['pincode'];
    return addressTokens;
  }

  Map toJson() => {
        "houseNumber": houseNumber,
        "houseName": houseName,
        "poi": poi,
        "street": street,
        "subSubLocality": subSubLocality,
        "subLocality": subLocality,
        "locality": locality,
        "village": village,
        "subDistrict": subDistrict,
        "district": district,
        "city": city,
        "state": state,
        "pincode": pincode,
      };
}
